package Align3TP;

/**
 * Records history for undo
  *
 * @author J. Anthony Parker, MD PhD <J.A.Parker@IEEE.org>
 * @version 7January2002
 *
 * @see Align3TP.Alignment
 */

class History {
	private int number;
	private String name;
	private History prior;
	private Affine[] view = new Affine[2],
					reg = new Affine[2];
	private double[] weight = new double[2];
	private boolean[] interpolate = new boolean[2];
	private short flipped;

	History(String name, History prior,
					ImagePlusPlus[] imppIn, Handedness hand) {
		this.prior = prior;
		if(prior == null)
			number = 1;
		else
			number = 1 + prior.getNumber();
		this.name = new Integer(number).toString() + ": " + name;
		for(int i=0; i<2; i++) {
			this.view[i] = new Affine(imppIn[i].getView());
			this.reg[i] = new Affine(imppIn[i].getReg());
			this.weight[i] = imppIn[i].getWeight();
			this.interpolate[i] =imppIn[i].getInterpolate();
		}
		this.flipped = hand.getFlipped();
		return;
	}

	void undo(ImagePlusPlus[] imppIn, Handedness hand) {
		for (int i=0; i<2; i++) {
			imppIn[i].setView(this.view[i]);
			imppIn[i].setReg(this.reg[i]);
			imppIn[i].setWeight(this.weight[i]);
			imppIn[i].setInterpolate(this.interpolate[i]);
		}
		hand.setFlipped(this.flipped);
		return;
	}

	History getPrior() {
		return prior;
	}

	int getNumber() {
		return number;
	}

	String getName() {
		return name;
	}

}
